:py:mod:`piel.models.frequency.photonic.grating_coupler`
========================================================

.. py:module:: piel.models.frequency.photonic.grating_coupler

.. autoapi-nested-parse::

   Translated from https://github.com/flaport/sax or https://github.com/flaport/photontorch/tree/master



Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.models.frequency.photonic.grating_coupler.grating_coupler_simple



.. py:function:: grating_coupler_simple(R=0.0, R_in=0.0, Tmax=1.0, bandwidth=6e-08, wl0=1.55e-06)
